@@ -1,6 +1,11 @@
 ## classify function
 MSIseq.classify <- function(mutationNum, classifier = NGSclassifier, cancerType = NULL) {
   
+  ## check mutationNum file
+  if(!all(c("T.sns", "S.sns", "T.ind", "S.ind", "T", "S", "ratio.sns", "ratio.ind", "ratio")%in%colnames(mutationNum))){
+    	stop("Wrong column names in mutationNum.")
+  }
+  
   ## check the cancerType file
   if (is.null(cancerType)) {
   	classifyset = mutationNum
@@ -21,10 +26,15 @@ MSIseq.classify <- function(mutationNum, classifier = NGSclassifier, cancerType
   	colnames(classifyset)[ncol(classifyset)] = "cancer_type"
   }
 
-
+  ## flag likely POLE deficent samples
+  POLE = (mutationNum$T.sns>60)&(mutationNum$S.ind<0.18)
+  POLE = as.character(POLE)
+  POLE[POLE=="FALSE"] = "No"
+  POLE[POLE=="TRUE"] = "Yes"
+  
   classify.result = predict(classifier, newdata=classifyset, type="class")
   result = as.data.frame(cbind(rownames(classifyset), 
-  as.character(classify.result)))
-  colnames(result) = c("Tumor_Sample_Barcode", "MSI_status")
+  as.character(classify.result), POLE))
+  colnames(result) = c("Tumor_Sample_Barcode", "MSI_status", "Likely_POLE_deficiency")
   result
 } 
